@@ -13,7 +13,7 @@ from functools import partial
 from os.path import join
 from warnings import warn
 from typing import (
-    Any, Callable, Optional, Union, ClassVar, Mapping, Iterator, Type, Dict, TypeVar, Tuple
+    Any, Callable, Optional, Union, ClassVar, Mapping, Iterator, Type, Dict, TypeVar, Tuple, List
 )
 
 import numpy as np
@@ -67,7 +67,7 @@ class Result:
                  dill_path: "None | str | os.PathLike[str]" = None,
                  plams_dir: "None | str | os.PathLike[str]" = None,
                  work_dir: "None | str | os.PathLike[str]" = None,
-                 status: str = 'done',
+                 status: str = 'successful',
                  warnings: Optional[WarnMap] = None) -> None:
         """Initialize a :class:`Result` instance.
 
@@ -152,6 +152,12 @@ class Result:
             """, category=QMFlows_Warning, stacklevel=2)
         return None
 
+    def __dir__(self) -> List[str]:
+        """Implement ``dir(self)``."""
+        # Insert the highly dynamic `get_property`-based attributes
+        dir_set = set(super().__dir__()) | self.prop_mapping.keys()
+        return sorted(dir_set)
+
     def get_property(self, prop: str) -> Any:
         """Look for the optional arguments to parse a property, which are stored in the properties dictionary."""  # noqa
         try:
